@@ -5,6 +5,7 @@ import zipfile
 from datetime import datetime
 from pathlib import Path
 from typing import TYPE_CHECKING, Callable, List, Optional
+from urllib import parse
 
 from darwin.dataset.download_manager import download_all_images_from_annotations
 from darwin.dataset.identifier import DatasetIdentifier
@@ -12,6 +13,7 @@ from darwin.dataset.release import Release
 from darwin.dataset.upload_manager import add_files_to_dataset
 from darwin.dataset.utils import exhaust_generator, get_annotations, get_classes, make_class_lists, split_dataset
 from darwin.exceptions import NotFound
+from darwin.item import parse_dataset_item
 from darwin.utils import find_files, urljoin
 from darwin.validators import name_taken, validation_error
 
@@ -69,6 +71,7 @@ class RemoteDataset:
         fps: int = 1,
         files_to_exclude: Optional[List[str]] = None,
         resume: bool = False,
+        path: Optional[str] = None,
     ):
         """Uploads a local dataset (images ONLY) in the datasets directory.
 
@@ -87,6 +90,8 @@ class RemoteDataset:
             Number of file per seconds to upload
         resume : bool
             Flag for signalling the resuming of a push
+        path: str
+            Optional path to put the files into
 
         Returns
         -------
@@ -96,6 +101,10 @@ class RemoteDataset:
             The files count
         """
 
+        # paths needs to start with /
+        if path and path[0] != "/":
+            path = f"/{path}"
+
         # This is where the responses from the upload function will be saved/load for resume
         self.local_path.parent.mkdir(exist_ok=True)
         responses_path = self.local_path.parent / ".upload_responses.json"
@@ -124,7 +133,12 @@ class RemoteDataset:
             raise ValueError("No files to upload, check your path, exclusion filters and resume flag")
 
         progress, count = add_files_to_dataset(
-            client=self.client, dataset_id=str(self.dataset_id), filenames=files_to_upload, fps=fps, team=self.team
+            client=self.client,
+            dataset_id=str(self.dataset_id),
+            filenames=files_to_upload,
+            fps=fps,
+            team=self.team,
+            path=path,
         )
 
         # If blocking is selected, upload the dataset remotely
@@ -149,7 +163,7 @@ class RemoteDataset:
         multi_threaded: bool = True,
         only_annotations: bool = False,
         force_replace: bool = False,
-        remove_extra: bool = True,
+        remove_extra: bool = False,
         subset_filter_annotations_function: Optional[Callable] = None,
         subset_folder_name: Optional[str] = None,
     ):
@@ -259,20 +273,37 @@ class RemoteDataset:
         """Archives (soft-deletion) the remote dataset"""
         self.client.put(f"datasets/{self.dataset_id}/archive", payload={}, team=self.team)
 
-    def fetch_remote_files(self):
+    def fetch_remote_files(self, filters: Optional[dict] = None):
         """Fetch and lists all files on the remote dataset"""
         base_url = f"/datasets/{self.dataset_id}/items"
         if not self.client.feature_enabled("WORKFLOW", self.team):
             base_url = f"/datasets/{self.dataset_id}/dataset_images"
-        cursor = "?page[size]=500"
+        parameters = {"page[size]": 500}
+        if filters:
+            for list_type in ["filenames", "statuses"]:
+                if list_type in filters:
+                    if type(filters[list_type]) is list:
+                        parameters[list_type] = ",".join(filters[list_type])
+                    else:
+                        parameters[list_type] = filters[list_type]
+            if "path" in filters:
+                parameters["path"] = filters["path"]
+
+        cursor = {}
         while True:
-            response = self.client.get(f"{base_url}{cursor}", team=self.team)
-            yield from response["items"]
+            response = self.client.get(f"{base_url}?{parse.urlencode({**parameters, **cursor})}", team=self.team)
+            yield from [parse_dataset_item(item) for item in response["items"]]
             if response["metadata"]["next"]:
-                cursor = f"?page[from]={response['metadata']['next']}"
+                cursor["page[from]"] = response["metadata"]["next"]
             else:
                 return
 
+    def archive(self, items):
+        self.client.put(f"datasets/{self.dataset_id}/items/archive", {"ids": [item.id for item in items]})
+
+    def restore_archived(self, items):
+        self.client.put(f"datasets/{self.dataset_id}/items/restore", {"ids": [item.id for item in items]})
+
     def fetch_annotation_type_id_for_name(self, name: str):
         """Fetches annotation type id for a annotation type name, such as bounding_box"""
         annotation_types = self.client.get("/annotation_types")
@@ -496,6 +527,9 @@ class RemoteDataset:
         ):
             yield annotation
 
+    def workview_url_for_item(self, item):
+        return urljoin(self.client.base_url, f"/workview?dataset={self.dataset_id}&image={item.seq}")
+
     @property
     def remote_path(self) -> Path:
         """Returns an URL specifying the location of the remote dataset"""
