@@ -63,7 +63,7 @@ def import_annotations(
     file_paths: List[Union[str, Path]],
 ):
     print("Fetching remote file list...")
-    remote_files = {f["filename"]: f["id"] for f in dataset.fetch_remote_files()}
+    remote_files = {f.filename: f.id for f in dataset.fetch_remote_files()}
     print("Fetching remote class list...")
     remote_classes = build_main_annotations_lookup_table(dataset.fetch_remote_classes())
     attributes = build_attribute_lookup(dataset)
@@ -138,6 +138,6 @@ def _import_annotations(client: "Client", id: int, remote_classes, attributes, a
     if client.feature_enabled("WORKFLOW", dataset.team):
         res = client.post(f"/dataset_items/{id}/import", payload={"annotations": serialized_annotations})
         if res["status_code"] != 200:
-            print(f"warning, failed to upload annotation to {id}")
+            print(f"warning, failed to upload annotation to {id}", res)
     else:
         client.post(f"/dataset_images/{id}/import", payload={"annotations": serialized_annotations})
